@@ -326,7 +326,11 @@ class MainWindow(object):
 
 	def __init__(self, parent, app):
 		self._app = app
-		self._session = session.Session(constants._data_path_)
+
+		self._errorLog = qui_utils.QErrorLog()
+		self._errorDisplay = qui_utils.ErrorDisplay(self._errorLog)
+
+		self._session = session.Session(self._errorLog, constants._data_path_)
 		self._session.error.connect(self._on_session_error)
 		self._session.loggedIn.connect(self._on_login)
 		self._session.loggedOut.connect(self._on_logout)
@@ -338,9 +342,7 @@ class MainWindow(object):
 		self._credentialsDialog = None
 		self._smsEntryDialog = None
 		self._accountDialog = None
-
-		self._errorLog = qui_utils.QErrorLog()
-		self._errorDisplay = qui_utils.ErrorDisplay(self._errorLog)
+		self._aboutDialog = None
 
 		self._tabsContents = [
 			DelayedWidget(self._app, self._TAB_SETTINGS_NAMES[i])
@@ -402,6 +404,10 @@ class MainWindow(object):
 		self._refreshTabAction.setShortcut(QtGui.QKeySequence("CTRL+r"))
 		self._refreshTabAction.triggered.connect(self._on_refresh)
 
+		self._aboutAction = QtGui.QAction(None)
+		self._aboutAction.setText("About")
+		self._aboutAction.triggered.connect(self._on_about)
+
 		self._closeWindowAction = QtGui.QAction(None)
 		self._closeWindowAction.setText("Close")
 		self._closeWindowAction.setShortcut(QtGui.QKeySequence("CTRL+w"))
@@ -415,6 +421,7 @@ class MainWindow(object):
 			toolsMenu = self._window.menuBar().addMenu("&Tools")
 			toolsMenu.addAction(self._accountTabAction)
 			toolsMenu.addAction(self._importTabAction)
+			toolsMenu.addAction(self._aboutAction)
 
 			self._window.addAction(self._closeWindowAction)
 			self._window.addAction(self._app.quitAction)
@@ -432,6 +439,7 @@ class MainWindow(object):
 			toolsMenu = self._window.menuBar().addMenu("&Tools")
 			toolsMenu.addAction(self._accountTabAction)
 			toolsMenu.addAction(self._importTabAction)
+			toolsMenu.addAction(self._aboutAction)
 
 		self._window.addAction(self._app.logAction)
 
@@ -449,7 +457,14 @@ class MainWindow(object):
 		return self._defaultCredentials
 
 	def walk_children(self):
-		return ()
+		return (diag for diag in (
+			self._credentialsDialog,
+			self._smsEntryDialog,
+			self._accountDialog,
+			self._aboutDialog,
+			)
+			if diag is not None
+		)
 
 	def start(self):
 		assert self._session.state == self._session.LOGGEDOUT_STATE
@@ -462,7 +477,6 @@ class MainWindow(object):
 
 	def close(self):
 		for child in self.walk_children():
-			child.window.destroyed.disconnect(self._on_child_close)
 			child.close()
 		self._window.close()
 
@@ -573,68 +587,85 @@ class MainWindow(object):
 	@QtCore.pyqtSlot(str)
 	@misc_utils.log_exception(_moduleLogger)
 	def _on_session_error(self, message):
-		self._errorLog.push_message(message)
+		with qui_utils.notify_error(self._errorLog):
+			self._errorLog.push_error(message)
 
 	@QtCore.pyqtSlot()
 	@misc_utils.log_exception(_moduleLogger)
 	def _on_login(self):
-		if self._defaultCredentials != self._curentCredentials:
-			self._show_account_dialog()
-		self._defaultCredentials = self._curentCredentials
-		for tab in self._tabsContents:
-			tab.enable()
+		with qui_utils.notify_error(self._errorLog):
+			if self._defaultCredentials != self._curentCredentials:
+				self._show_account_dialog()
+			self._defaultCredentials = self._curentCredentials
+			for tab in self._tabsContents:
+				tab.enable()
 
 	@QtCore.pyqtSlot()
 	@misc_utils.log_exception(_moduleLogger)
 	def _on_logout(self):
-		for tab in self._tabsContents:
-			tab.disable()
+		with qui_utils.notify_error(self._errorLog):
+			for tab in self._tabsContents:
+				tab.disable()
 
 	@QtCore.pyqtSlot()
 	@misc_utils.log_exception(_moduleLogger)
 	def _on_recipients_changed(self):
-		if self._session.draft.get_num_contacts() == 0:
-			return
+		with qui_utils.notify_error(self._errorLog):
+			if self._session.draft.get_num_contacts() == 0:
+				return
 
-		if self._smsEntryDialog is None:
-			import dialogs
-			self._smsEntryDialog = dialogs.SMSEntryWindow(self.window, self._app, self._session, self._errorLog)
-		pass
+			if self._smsEntryDialog is None:
+				import dialogs
+				self._smsEntryDialog = dialogs.SMSEntryWindow(self.window, self._app, self._session, self._errorLog)
 
 	@QtCore.pyqtSlot()
 	@QtCore.pyqtSlot(bool)
 	@misc_utils.log_exception(_moduleLogger)
 	def _on_login_requested(self, checked = True):
-		self._prompt_for_login()
+		with qui_utils.notify_error(self._errorLog):
+			self._prompt_for_login()
 
 	@QtCore.pyqtSlot(int)
 	@misc_utils.log_exception(_moduleLogger)
 	def _on_tab_changed(self, index):
-		self._currentTab = index
-		self._initialize_tab(index)
+		with qui_utils.notify_error(self._errorLog):
+			self._currentTab = index
+			self._initialize_tab(index)
 
 	@QtCore.pyqtSlot()
 	@QtCore.pyqtSlot(bool)
 	@misc_utils.log_exception(_moduleLogger)
 	def _on_refresh(self, checked = True):
-		self._tabsContents[self._currentTab].refresh(force=True)
+		with qui_utils.notify_error(self._errorLog):
+			self._tabsContents[self._currentTab].refresh(force=True)
 
 	@QtCore.pyqtSlot()
 	@QtCore.pyqtSlot(bool)
 	@misc_utils.log_exception(_moduleLogger)
 	def _on_import(self, checked = True):
-		csvName = QtGui.QFileDialog.getOpenFileName(self._window, caption="Import", filter="CSV Files (*.csv)")
-		if not csvName:
-			return
-		import shutil
-		shutil.copy2(csvName, self._app.fsContactsPath)
-		self._tabsContents[self.CONTACTS_TAB].update_addressbooks()
+		with qui_utils.notify_error(self._errorLog):
+			csvName = QtGui.QFileDialog.getOpenFileName(self._window, caption="Import", filter="CSV Files (*.csv)")
+			if not csvName:
+				return
+			import shutil
+			shutil.copy2(csvName, self._app.fsContactsPath)
+			self._tabsContents[self.CONTACTS_TAB].update_addressbooks()
 
 	@QtCore.pyqtSlot()
 	@QtCore.pyqtSlot(bool)
 	@misc_utils.log_exception(_moduleLogger)
 	def _on_account(self, checked = True):
-		self._show_account_dialog()
+		with qui_utils.notify_error(self._errorLog):
+			self._show_account_dialog()
+
+	@QtCore.pyqtSlot()
+	@QtCore.pyqtSlot(bool)
+	def _on_about(self, checked = True):
+		with qui_utils.notify_error(self._errorLog):
+			if self._aboutDialog is None:
+				import dialogs
+				self._aboutDialog = dialogs.AboutDialog(self._app)
+			response = self._aboutDialog.run()
 
 	@QtCore.pyqtSlot()
 	@QtCore.pyqtSlot(bool)
